@@ -118,11 +118,12 @@ class DingtalkPlugin(notify.NotificationPlugin):
             return
         url = self.get_webhook_urls(group.project)
         link = self.get_group_url(group)
-        message_format = '[Error]\n[%s]\n%s\n%s'
-        message = message_format % (event.title, event.message, link)
-        data = {"msgtype": "text",
-                    "text": {
-                        "content": message
+        message_format = '%s\n%s'
+        message = message_format % (event.message, link)
+        data = {"msgtype": "markdown",
+                    "markdown": {
+                        "title": event.title
+                        "text": message
                     }
                 }
         headers = {'Content-type': 'application/json', 'Accept': 'text/plain'}
